<?php
/**
 * @version     1.0.2
 * @package     com_gadecisions
 * @copyright   Copyright (C) 2020-2020. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Glenn Arkell <glenn@glennarkell.com.au> - http://www.glennarkell.com.au
 */

namespace GlennArkell\Component\Gadecisions\Administrator\Field;

// No direct access to this file
defined('_JEXEC') or die;

// import the list field type
use \Joomla\CMS\Form\FormField;
use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Form\Field\ListField;
use \GlennArkell\Component\Gadecisions\Administrator\Helper\GadecisionsHelper;

class MotionsField extends ListField
{
    /**
     * The field type.
     *
     * @var         string
     */
    protected $type = 'Motions';

	/**
	 * Name of the layout being used to render the field
	 * @var    string
	 * @since  4.0.0
	 */
	protected $layout = 'joomla.form.field.list';

    /**
     * Method to get a list of options for a list input.
     * @return      array           An array of JHtml options.
     */
    protected function getOptions()
    {
        $options = GadecisionsHelper::getMotionOptions();

        if (is_null($options)) { $options = array(); }
        
        foreach ($options as $opt) {
            if ($opt->value) {
                $motion = GadecisionsHelper::getMotion($opt->value);
                $newTxt = $motion->title.' - '.Text::_('COM_GADECISIONS_FORM_LBL_MOTION_MOV_ID').' '.$motion->mov_id_name;
                $newTxt .= ' '.Text::_('COM_GADECISIONS_ON').' ';
                $newTxt .= HTMLHelper::_('date', $motion->motion_date, Text::_('COM_GADECISIONS_DISPLAY_DATE'));
                $newTxt .= ' '.Text::_('COM_GADECISIONS_FOR_GROUP').' '.$motion->group_id_name;
                $opt->text = $newTxt;
                $newOpts[] = $opt;
            } else {
                $newOpts[] = $opt;
            }
        }

        $options = array_merge(parent::getOptions(), $newOpts);

        return $options;
    }
}
