<?php
/**
 * @version    1.0.2
 * @package    com_gadecisions
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2021 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Uri\Uri;
use \Joomla\Utilities\ArrayHelper;
use \Joomla\Component\Fields\Administrator\Helper\FieldsHelper;
use \GlennArkell\Component\Gadecisions\Administrator\Helper\GadecisionsHelper;
use \GlennArkell\Component\Gadecisions\Administrator\Helper\GamodalHelper;

// load any assets required
$this->document->getWebAssetManager()
    ->usePreset('com_gadecisions.gadecisionspreset');

// Load admin language file
$lang = Factory::getLanguage();
$lang->load('com_gadecisions', JPATH_ADMINISTRATOR);

$app = Factory::getApplication();
$menuID = $app->getMenu()->getActive()->id;
$app->setUserState('com_gadecisions.menu.itemId', $menuID);

$user = GadecisionsHelper::getSpecificUser();
$canEdit = GadecisionsHelper::canUserEdit($user, $this->item);
$hasVoted = GadecisionsHelper::hasVoted($user->id, $this->item->id, false);
$deciderVoted = GadecisionsHelper::hasVoted($this->item->decider, $this->item->id, true);
$state = $this->item->reqsec ? 'Published' : 'Not Published';
$today = Factory::getDate()->toSql();

$canDelete = $user->authorise('core.delete','com_gadecisions.motion.'.$this->item->id);
$this->canAdmin = $user->authorise('core.manage','com_gadecisions');
$canVote = $user->authorise('core.vote','com_gadecisions');

$removeTran = GadecisionsHelper::getHTTPQuery(null, 'task', 'motion.remove', 'id', $this->item->id);
$removeURL = 'index.php?'.\http_build_query($removeTran, '', '&amp;');
$editTran = GadecisionsHelper::getHTTPQuery(null, 'task', 'motion.edit', 'id', $this->item->id);
$editURL = 'index.php?'.\http_build_query($editTran, '', '&amp;');
$canTran = GadecisionsHelper::getHTTPQuery(null, 'task', 'motion.cancel', 'id', $this->item->id);
$canURL = 'index.php?'.\http_build_query($canTran, '', '&amp;');
$showResult = $today > $this->item->expiry_date ? true : false;
$voteBtn = GamodalHelper::setupModalButton('view', 'motionform', 'id', $this->item->id, 'modalvote', 'myVoteModal', 'info', 'COM_GADECISIONS_VOTE', 'COM_GADECISIONS_CAST_VOTE', 'fas fa-person-booth', $user->name);
$deciderBtn = '';
if ($this->item->votes_for > $this->item->votes_against) {
    $result = Text::_('COM_GADECISIONS_CARRIED');
} elseif ($this->item->votes_for < $this->item->votes_against) {
    $result = Text::_('COM_GADECISIONS_REJECTED');
} else {
    $result = Text::_('COM_GADECISIONS_EQUAL_DECIDER');
    if ($this->canAdmin && !$this->item->decider) {
        $deciderBtn = GamodalHelper::setupModalButton('view', 'motionform', 'id', $this->item->id, 'modalnom', 'myNomModal', 'warning', 'Decider', 'COM_GADECISIONS_SET_DECIDER', 'fas fa-person', '');
    }
}
// show vote button if decider required and only for decider
if ($showResult && $this->item->decider && $this->item->decider == $user->id && !$deciderVoted) {
    $hasVoted = false; $showResult = false;
}

// get custom field details if required
$fields = FieldsHelper::getFields('com_gadecisions.motionform', null, true);
$fldName = '';
$options = '';
foreach ($fields as $fld) { 
    if ($this->item->field_id != $fld->id) { continue; }
    $opts = ArrayHelper::fromObject($fld->fieldparams->get('options'));
    $fldName = $fld->title;
    foreach ($opts as $opt) {
        $voteCount = GadecisionsHelper::countCFVotes($this->item->id, $this->item->field_id, $opt['value']);
        $options .= $opt['value'].' ('.Text::_($opt['name']).') <strong>'.Text::_('COM_GADECISIONS_VOTES_COUNTED').': '.$voteCount.'</strong><br />';
    }
}

// Display a heading for the page
if ($this->params->get('page_title', '') > '') {
	echo '<h2>'.$this->params->get('page_title').'</h2>';
} else { 
	echo '<h2>'.Text::_('COM_GADECISIONS_TITLE_MOTION').'</h2>';
}

/*
echo '<pre>Test<br />';
print_r($lang->getTag());
echo '</pre>';
*/
?>

<style>
    a.btn {
        border: 1px solid #666 !important;
    }
</style>
<div class="item_fields">

	<table class="table">

		<tr>
			<th><?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_TITLE'); ?></th>
			<td><?php echo $this->item->title; ?></td>
		</tr>
		<?php if (!$this->params->get('details_last', 0)) : ?>
            <tr>
    			<th><?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_MOTION'); ?></th>
    			<td><?php echo $this->item->motion; ?></td>
    		</tr>
		<?php endif; ?>
		<tr>
			<th><?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_MOTION_DATE'); ?></th>
			<td><?php echo $this->item->motion_date > 0 ? HTMLHelper::_('date', $this->item->motion_date, Text::_('COM_GADECISIONS_DISPLAY_DATE')) : '-'; ?></td>
		</tr>
		<tr>
			<th><?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_MOV_ID'); ?></th>
			<td><?php echo $this->item->mov_id_name; ?></td>
		</tr>
		<?php if ($this->item->reqsec) : ?>
    		<tr>
    			<th><?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_REQSEC'); ?></th>
    			<td><?php echo $this->item->reqsec ? Text::_('JYES') : Text::_('JNO'); ?></td>
    		</tr>
    		<tr>
    			<th><?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_SEC_ID'); ?></th>
    			<td><?php echo $this->item->sec_id ? $this->item->sec_id_name : ''; ?></td>
    		</tr>
		<?php endif; ?>
		<tr>
			<th><?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_VOTERS_USER_GP'); ?></th>
			<td><?php echo $this->item->group_id ? $this->item->group_id_name : ''; ?></td>
		</tr>
		<tr>
			<th><?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_EXPIRY_DATE'); ?></th>
			<td><?php echo $this->item->expiry_date > 0 ? HTMLHelper::_('date', $this->item->expiry_date, Text::_('COM_GADECISIONS_DISPLAY_DATE')) : '-'; ?></td>
		</tr>
		<?php if ($this->params->get('details_last', 0)) : ?>
            <tr>
    			<th><?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_MOTION'); ?></th>
    			<td><?php echo $this->item->motion; ?></td>
    		</tr>
		<?php endif; ?>

		<?php if ($showResult) { echo '<tr><th>' . $deciderBtn . '</th><td><h5 style="text-align:center;">' . $result . '</h5></td></tr>'; } ?>
		<?php if($this->canAdmin) : ?>
    		<?php if ($this->item->field_id) : ?>
                <tr>
        			<th><?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_VOTE'); ?></th>
        			<td><?php echo $fldName.'<br />'.$options; ?></td>
        		</tr>
    		<?php else : ?>
                <tr>
        			<th><?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_VOTE'); ?></th>
        			<td>
                        <?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_VOTES_FOR').': '.$this->item->votes_for.'<br />'; ?>
                        <?php echo Text::_('COM_GADECISIONS_FORM_LBL_MOTION_VOTES_AGAINST').': '.$this->item->votes_against.'<br />'; ?>
                    </td>
        		</tr>
    		<?php endif; ?>

    		<tr>
    			<th><?php echo Text::_('COM_GADECISIONS_TITLE_SYSINFO'); ?></th>
    			<td>
                    <?php echo Text::_('COM_GADECISIONS_FORM_LBL_ID').': '.$this->item->id.'<br />'; ?>
                    <?php echo Text::_('COM_GADECISIONS_FORM_LBL_STATE').': '.$state.'<br />'; ?>
                    <?php echo Text::_('COM_GADECISIONS_FORM_LBL_CREATED_DATE').': '.$this->item->created_date.'<br />'; ?>
                    <?php echo Text::_('COM_GADECISIONS_FORM_LBL_MODIFIED_DATE').': '.$this->item->modified_date.'<br />'; ?>
                    <?php echo Text::_('COM_GADECISIONS_FORM_LBL_COMMENT').': <br />'.nl2br($this->item->comment); ?>
                </td>
    		</tr>
		<?php endif; ?>

	</table>

</div>

<?php /* ----------------------   Return button   ------------------------------ */ ?>
<?php if(!isset($this->item->menu_motion_id)) : ?>
    <a class="btn btn-secondary" href="<?php echo Route::_($canURL); ?>">
    	<i class="icon-undo"></i> <?php echo Text::_("COM_GADECISIONS_RETURN"); ?>
    </a>
<?php endif; ?>

<?php /* ----------------------   Vote button   ------------------------------ */ ?>
<?php echo !$hasVoted && $canVote && !$showResult ? $voteBtn : ''; ?>

<?php /* ----------------------   Edit button   ------------------------------ */ ?>
<?php if($this->canAdmin && $this->item->checked_out == 0 && !$showResult): ?>
	<a class="btn btn-warning" href="<?php echo Route::_($editURL); ?>">
		<i class="icon-edit"></i> <?php echo Text::_("COM_GADECISIONS_EDIT_ITEM"); ?>
	</a>
<?php endif; ?>

<?php /* ----------------------   Delete button and modal  ------------------------------ */ ?>
<?php if ($canDelete && !$showResult) : ?>
	<a href="<?php echo Route::_($removeURL, false, 2); ?>" class="btn btn-danger delete-button" type="button">
        <i class="icon-trash" ></i>
    </a>
    <script type="text/javascript">
    	jQuery(document).ready(function () {
    		jQuery('.delete-button').click(deleteItem);
    	});
    	function deleteItem() {
    		if (!confirm("<?php echo Text::_('COM_GADECISIONS_DELETE_MESSAGE'); ?>")) {
    			return false;
    		}
    	}
    </script>
<?php endif; ?>

<?php if($this->canAdmin): ?>
<div class="item_fields">
	<table class="table">
		<tr>
			<th><?php echo Text::_('COM_GADECISIONS_MOTIONS_MEMBERS_VOTED'); ?></th>
			<td>
                <?php if (!empty($this->item->voters)) : ?>
                    <?php foreach ($this->item->voters AS $voter) : ?>
                        <?php echo $voter->user_id == $voter->decider ? '<span style="color:#a51f18;">'.$voter->name.'</span>, ' : $voter->name.', '; ?>
                    <?php endforeach; ?>
                    <br />
                    <?php echo Text::_('COM_GADECISIONS_MOTIONS_MEMBERS_VOTED_DESC'); ?>
                <?php else : ?>
                    <?php echo Text::_('COM_GADECISIONS_NO_VOTES_COUNTED_AS_YET'); ?>
                <?php endif; ?>
            </td>
		</tr>
	</table>
</div>
<?php endif; ?>
