<?php
/**
 * @version    1.0.2
 * @package    com_gadecisions
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2021 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\HTML\HTMLHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Router\Route;
use \Joomla\CMS\Language;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Layout\LayoutHelper;
use \Joomla\Utilities\ArrayHelper;
use \Joomla\Component\Fields\Administrator\Helper\FieldsHelper;
use \GlennArkell\Component\Gadecisions\Administrator\Helper\GadecisionsHelper;
use \GlennArkell\Component\Gadecisions\Administrator\Helper\GamodalHelper;

// load any assets required
$this->document->getWebAssetManager()
    ->usePreset('com_gadecisions.gadecisionspreset');

// Load admin language file
$lang = Factory::getLanguage();
$lang->load('com_gadecisions', JPATH_ADMINISTRATOR);

$app = Factory::getApplication();
$menuID = $app->getMenu()->getActive()->id;
$app->setUserState('com_gadecisions.menu.itemId', $menuID);

$listOrder  = $this->state->get('list.ordering','a.expiry_date');
$listDirn   = $this->state->get('list.direction','asc');

$user       = GadecisionsHelper::getSpecificUser();
$canCreate  = $user->authorise('core.create', 'com_gadecisions');
$canEdit    = $user->authorise('core.edit', 'com_gadecisions');
$canCheckin = $user->authorise('core.manage', 'com_gadecisions');
$this->canAdmin = $user->authorise('core.admin', 'com_gadecisions');
$canChange  = $user->authorise('core.edit.state', 'com_gadecisions');
$canEditOwn  = $user->authorise('core.edit.own', 'com_gadecisions');
$canDelete  = $user->authorise('core.delete', 'com_gadecisions');
$canVote  = $user->authorise('core.vote', 'com_gadecisions');
$spacer10 = ' &nbsp; &nbsp; &nbsp; &nbsp; &nbsp;';

$baseURL = 'index.php?';
$createTran = GadecisionsHelper::getHTTPQuery(null, 'task', 'motion.edit', 'id', 0);
$createURL = $baseURL.\http_build_query($createTran, '', '&amp;');
$today = Factory::getDate()->toSql();

//GadecisionsHelper::gaprint($menuID);
/*
$tmpl = Factory::getApplication()->getTemplate(true);
$tmplCSS = JPATH_BASE.'/media/templates/site/cassiopeia/css/template.css';
GadecisionsHelper::gaprint($menuID);
$menuitem = Factory::getApplication()->getMenu()->getActive();
print_r(Factory::getApplication()->getUserState('com_gadecisions.test.data'));
*/

// Display a heading for the page
if ($this->params->get('page_title', '') > '') {
	echo '<div class="page-header"><h1 itemprop="headline">'.$this->params->get('page_title').'</h1></div>';
} else { 
	echo '<div class="page-header"><h1 itemprop="headline">'.Text::_('COM_GADECISIONS_TITLE_MOTIONS').'</h1></div>';
}
?>
<style>
    a.btn {
        border: 1px solid #666 !important;
    }
</style>

<form action="<?php echo htmlspecialchars(Uri::getInstance()->toString()); ?>" method="post"
      name="adminForm" id="adminForm" class="com-content-category__articles">

	<?php echo LayoutHelper::render('default_filter', array('view' => $this), dirname(__FILE__)); ?>

    <?php if (!empty($this->items)) : ?>
        <div class="table-responsive com-contact-categories categories-list">
    	<table class="table table-striped" id="motionList">
    		<thead>
    		<tr>
    			<th class=''>
    				<?php echo HTMLHelper::_('grid.sort',  'COM_GADECISIONS_MOTIONS_MOTION', 'a.title', $listDirn, $listOrder); ?>
    			</th>
    
    			<?php if ($this->canAdmin): ?>
    				<th class="center">
    					<?php echo Text::_('COM_GADECISIONS_ACTIONS'); ?>
    				</th>
    			<?php endif; ?>
    
    		</tr>
    		</thead>
    		<tfoot>
    		<tr>
    			<td colspan="<?php echo isset($this->items[0]) ? count(get_object_vars($this->items[0])) : 10; ?>">
    				<?php echo $this->pagination->getListFooter(); ?>
    			</td>
    		</tr>
    		</tfoot>
    		<tbody>
    		<?php foreach ($this->items as $i => $item) : ?>
    			<?php
                    if ($item->group_id && !in_array($item->group_id, $user->groups) && !$this->canAdmin) { continue; }

                    $canEdit = GadecisionsHelper::canUserEdit($user, $item);
    
                    $linkTran = GadecisionsHelper::getHTTPQuery(null, 'view', 'motion', 'id', $item->id);
                    $appURL = $baseURL.\http_build_query($linkTran, '', '&amp;');
    
                    $editTran = GadecisionsHelper::getHTTPQuery(null, 'task', 'motion.edit', 'id', $item->id);
                    $editURL = $baseURL.\http_build_query($editTran, '', '&amp;');
    
                    $removeTran = GadecisionsHelper::getHTTPQuery(null, 'task', 'motion.remove', 'id', $item->id);
                    $removeURL = $baseURL.\http_build_query($removeTran, '', '&amp;');
    
                    $archTran = GadecisionsHelper::getHTTPQuery(null, 'task', 'motion.publish', 'id', $item->id);
                    $archTran = GadecisionsHelper::getHTTPQuery($archTran, null, null, 'state', 2);
                    $archURL = $baseURL.\http_build_query($archTran, '', '&amp;');

                    $anomTran = GadecisionsHelper::getHTTPQuery(null, 'task', 'motion.notify', 'id', $item->id);
                    $anomURL = $baseURL.\http_build_query($anomTran, '', '&amp;');

                    $voteBtn = GamodalHelper::setupModalButton('view', 'motionform', 'id', $item->id, 'modalvote', 'myVoteModal', 'info', 'COM_GADECISIONS_VOTE', 'COM_GADECISIONS_CAST_VOTE', 'fas fa-person-booth', $user->name);
                    $hasVoted = GadecisionsHelper::hasVoted($user->id, $item->id, false);
                    $deciderVoted = GadecisionsHelper::hasVoted($item->decider, $item->id, true);

                    $showResult = $today > $item->expiry_date ? true : false;
                    
                    // set the result and show decider button if necessary
                    $deciderBtn = '';
                    if ($item->votes_for > $item->votes_against) {
                        $result = Text::_('COM_GADECISIONS_CARRIED');
                    } elseif ($item->votes_for < $item->votes_against) {
                        $result = Text::_('COM_GADECISIONS_REJECTED');
                    } else {
                        $result = Text::_('COM_GADECISIONS_EQUAL_DECIDER');
                        if ($this->canAdmin && !$item->decider) {
                            $deciderBtn = GamodalHelper::setupModalButton('view', 'motionform', 'id', $item->id, 'modalnom', 'myNomModal', 'warning', 'COM_GADECISIONS_FORM_LBL_MOTION_DECIDER', 'COM_GADECISIONS_SET_DECIDER', 'fas fa-person', '');
                        }
                    }

                    // show vote button if decider required and only for decider
                    if ($showResult && $item->decider && $item->decider == $user->id && !$deciderVoted) {
                        $hasVoted = false; $showResult = false;
                    }

                    // check for voting anomolies
                    $voteEqual = GadecisionsHelper::checkVotingNumbers($item->id);

                ?>

    			<tr class="row<?php echo $i % 2; ?>">

    				<td>
    					<?php if (isset($item->checked_out) && $item->checked_out) : ?>
    						<?php echo HTMLHelper::_('jgrid.checkedout', $i, $item->uEditor, $item->checked_out_time, 'motions.', $canCheckin); ?>
    					<?php endif; ?>
    					<p><strong><a href="<?php echo Route::_($appURL); ?>" title="<?php echo Text::_('COM_GADECISIONS_VIEW'); ?>"><?php echo $item->title; ?></a></strong></p>

                        <?php if (!$this->params->get('details_last', 0)) { echo $item->motion. '<br />'; } ?>

                        <?php echo '<strong>' . Text::_('COM_GADECISIONS_FORM_LBL_MOTION_EXPIRY_DATE').': </strong>'; ?>
    					<?php echo $item->expiry_date > 0 ? HTMLHelper::_('date', $item->expiry_date, Text::_('COM_GADECISIONS_DISPLAY_DATE')) : '-'; ?>
    					<?php echo $spacer10 . '<strong>' . Text::_('COM_GADECISIONS_FORM_LBL_MOTION_MOV_ID') . ': </strong>' . $item->mov_id_name; ?>
    					<?php echo $item->sec_id > 0 ? $spacer10 . '<strong>' . Text::_('COM_GADECISIONS_FORM_LBL_MOTION_SEC_ID') . ': </strong>' . $item->sec_id_name : ''; ?>
    					<?php echo $item->group_id > 0 ? $spacer10 . '<strong>' . Text::_('COM_GADECISIONS_FORM_LBL_MOTION_VOTERS_USER_GP') . ': </strong>' . $item->group_id_name : ''; ?>

                        <?php if ($this->params->get('details_last', 0)) { echo '<br /><br />'.$item->motion. '<br />'; } ?>

    					<?php echo !$hasVoted && $canVote && !$showResult ? $voteBtn.$spacer10 : ''; ?>

    					<?php if ($showResult) { echo '<br /><br />' . $deciderBtn . $spacer10 . '<h5 style="text-align:center;">' . $result . '</h5>'; } ?>

    					<?php if (!$voteEqual && $this->canAdmin) : ?>
        					<h5 style="text-align:center;">
                                <?php echo Text::_('COM_GADECISIONS_VOTING_ANOMALY');?> &nbsp;
                                <a href="<?php echo Route::_($anomURL, false, 2); ?>" class="btn btn-info" type="button" title="<?php echo Text::_('COM_GADECISIONS_NOTIFY'); ?>">
                                    <i class="icon-envelope" ></i>
                                </a>
                            </h5>
    					<?php endif; ?>
    				</td>

    				<?php if ($this->canAdmin): ?>
    					<td class="center">
    						<a href="<?php echo Route::_($archURL, false, 2); ?>" class="btn btn-info"
                                type="button" title="<?php echo Text::_('COM_GADECISIONS_ARCHIVED'); ?>">
                                <i class="icon-archive" ></i>
                            </a>
    						<?php if ($canEdit): ?>
    							<a href="<?php echo Route::_($editURL, false, 2); ?>" class="btn btn-warning"
                                    type="button" title="<?php echo Text::_('COM_GADECISIONS_EDIT'); ?>">
                                    <i class="icon-edit" ></i>
                                </a>
    						<?php endif; ?>
    						<?php if ($canDelete): ?>
    							<a href="<?php echo Route::_($removeURL, false, 2); ?>" class="btn btn-danger delete-button"
                                    type="button" title="<?php echo Text::_('COM_GADECISIONS_CANCEL'); ?>">
                                    <i class="icon-trash" ></i>
                                </a>
    						<?php endif; ?>
    					</td>
    				<?php endif; ?>
    
    			</tr>
    		<?php endforeach; ?>
    		</tbody>
    	</table>
            </div>
    	<?php if ($this->canAdmin) : ?>
    		<a href="<?php echo Route::_($createURL, false, 0); ?>" class="btn btn-success btn-small">
                <i class="icon-plus"></i> <?php echo Text::_('COM_GADECISIONS_ADD_ITEM'); ?>
            </a>
    	<?php endif; ?>
    
    <?php else : ?>
        <h3><?php echo Text::_('COM_GADECISIONS_NO_ITEMS'); ?></h3>
    <?php endif; ?>
	<input type="hidden" name="task" value=""/>
	<input type="hidden" name="boxchecked" value="0"/>
	<input type="hidden" name="filter_order" value="<?php echo $listOrder; ?>"/>
	<input type="hidden" name="filter_order_Dir" value="<?php echo $listDirn; ?>"/>
	<?php echo HTMLHelper::_('form.token'); ?>
</form>

<?php if($this->canAdmin) : ?>
<script type="text/javascript">

	jQuery(document).ready(function () {
		jQuery('.delete-button').click(deleteItem);
	});

	function deleteItem() {

		if (!confirm("<?php echo Text::_('COM_GADECISIONS_DELETE_MESSAGE'); ?>")) {
			return false;
		}
	}
</script>
<?php endif; ?>
